@@ -1,5 +1,7 @@
 import aiohttp
+import logging
 from abc import ABC, abstractmethod
+from google.auth.credentials import Credentials
 
 class AbstractAuth(ABC):
   """Abstract class to make authenticated requests."""
@@ -13,6 +15,10 @@ class AbstractAuth(ABC):
   async def async_get_access_token(self) -> str:
     """Return a valid access token."""
 
+  async def async_get_creds(self) -> Credentials:
+    """Return creds for subscriber API."""
+    return None
+
   async def request(self, method: str, url: str, **kwargs) -> aiohttp.ClientResponse:
     """Make a request."""
     headers = kwargs.get("headers")
@@ -25,6 +31,7 @@ class AbstractAuth(ABC):
 
     access_token = await self.async_get_access_token()
     headers["authorization"] = f"Bearer {access_token}"
-
-    return await self._websession.request(
-      method, f"{self._host}/{url}", **kwargs, headers=headers)
+    url = f"{self._host}/{url}"
+    logging.debug(f'request[{method}]={url}')
+    return await self._websession.request(method, url, **kwargs,
+        headers=headers)
